@@ -73,7 +73,8 @@ class DatabaseResource(Resource, Generic[GenericConfig]):
         return self.connection
 
     async def _migrations(self, schema_exists: bool, command):
-        path_exists = os.path.exists(os.path.join(os.getcwd(), self.db_conf.migrations_path))
+        path_exists = os.path.exists(os.path.join(os.getcwd(), self.db_conf.migrations_path)) and os.listdir(
+            os.path.join(os.getcwd(), self.db_conf.migrations_path))
 
         if not path_exists and not schema_exists:
             await self.create_schema(False)
